"""
Generic chain implementations.
"""

from hierachain.domains.generic.chains.base_chain import BaseChain
from hierachain.domains.generic.chains.domain_chain import DomainChain

__all__ = ['BaseChain', 'DomainChain']
