"""
Generic event implementations.
"""

from hierachain.domains.generic.events.base_event import BaseEvent
from hierachain.domains.generic.events.domain_event import DomainEvent

__all__ = ['BaseEvent', 'DomainEvent']
