"""
ERP adapters for various enterprise systems.
"""

# This module can be extended with specific ERP adapter implementations
# For now, the main ERP integrations are in the parent enterprise.py module

__all__ = []